@@ -1,8 +1,8 @@
 //#define XERR
 #include "agegroup.ih"
 
-    //  e.g.,   40 - 50:
-    //          70 - *:
+    //  e.g.,   40 - 50
+    //          70 - *
     // separating blanks are optional
 
 std::istream &AgeGroup::extract(std::istream &in)
@@ -19,5 +19,5 @@ std::istream &AgeGroup::extract(std::istream &in)
         in >> d_endAge;
     }
 
-    return in >> sep;                   // get the final ':' and return
+    return in;                          // return
 }
