@@ -11,7 +11,7 @@ std::ostream &operator<<(std::ostream &out, AgeGroup const &ageGroup)
     else
         out << ageGroup.d_endAge;
 
-    return out << ':';
+    return out;
 }
         
 
