@@ -3,5 +3,5 @@
 
 void AgeGroupVSD::vary()
 {
-    d_mean.vary();
+    d_vsd.vary();
 }
