@@ -10,7 +10,7 @@ Analysis::Analysis(std::istream &&stream, uint16_t lineNr)
 
     parser.load(stream, lineNr, d_labels, options); // read the analysis specs
 
-    alterOptions(options);                          
+    actualize(options);                          
 
     parser.load(Options::instance().configFile());  // read the config file
 }
