@@ -2,8 +2,8 @@
 #define INCLUDED_BEIR7_
 
 //Tumor:
-//        #     beta    eta     spread      dist
-//    Beir7:    .51     -2.0    .32         Normal  
+//        #     eta     beta    spread      dist
+//    Beir7:    -2.0    .51     .32         Normal  
 
 #include <iosfwd>
 
@@ -12,10 +12,8 @@
 
 class Beir7
 {
-    double d_beta;
-    double d_orgBeta;
-
-    VSD d_vsd;                  // contains eta and spread/distribution
+    double d_eta;       // beta;
+    VSD d_vsd;          // contains beta and spread/distribution
 
     public:
         Beir7();
@@ -25,19 +23,19 @@ class Beir7
         double spread() const;
         DistType distType() const;
 
-        void vary();
+        void vary(std::ostream &out);
 
         void writeParameters(std::ostream &out) const;
 };
 
 inline double Beir7::beta() const
 {
-    return d_beta;
+    return d_vsd.value();
 }
 
 inline double Beir7::eta() const
 {
-    return d_vsd.value();
+    return d_eta;
 }
 
 inline double Beir7::spread() const
