@@ -3,7 +3,7 @@
 
 void Costs::writeParameters(ostream &out) const
 {
-    Globals::setPrecision(out, 1) <<
+    Globals::setWidthPrec(out, 2, 1) <<
         "Costs:\n"
         "  biopsy:          " << setw(4) << d_biop << "\n"
         "  Discount:\n"
@@ -11,11 +11,13 @@ void Costs::writeParameters(ostream &out) const
         "    proportion:    " << setw(4) << d_discountProportion << "\n"
         "  diameters:\n";
     
+    Globals::setWidthPrec(out, 2, 0);
+
     for (size_t idx = 0; idx != d_treatment.size(); ++idx)
         out << 
-        "    diameter: >= " << 
+        "    diameter >= " << 
                 setw(6) << d_treatment[idx].first << " mm: " <<
                 setw(4) << d_treatment[idx].second << '\n';
 
-    Globals::setPrecision(out, 3) << '\n';
+    out.put('\n');
 }
