@@ -16,7 +16,7 @@ void Densities::add(bool *checkRange, LineInfo const &line)
 
     Err::Context context;
 
-    if (not Globals::proportions(density.birad(), N_BIRADS))
+    if (not proportions(density.birad()))
         context = Err::RANGE_0_1;
 
     else if (not density.sumOne())
