@@ -6,11 +6,11 @@
 // BreastDensities:
 // 
 //     #                bi-rad:  a      b      c      d
-//     agegroup:    0  - 40:    .05    .30    .48    .17
-//     agegroup:    40 - 50:    .06    .34    .47    .13
-//     agegroup:    50 - 60:    .08    .50    .37    .05
-//     agegroup:    60 - 70:    .15    .53    .29    .03
-//     agegroup:    70 - * :    .18    .54    .26    .02
+//     ageGroup:    0  - 40    .05    .30    .48    .17
+//     ageGroup:    40 - 50    .06    .34    .47    .13
+//     ageGroup:    50 - 60    .08    .50    .37    .05
+//     ageGroup:    60 - 70    .15    .53    .29    .03
+//     ageGroup:    70 - *     .18    .54    .26    .02
 
 #include <iosfwd>
 
@@ -38,6 +38,8 @@ class Densities
                                                 // birad idx for age, given 
                                                 // its probability
         uint16_t biradIdx(double age, double prob) const;
+
+        static bool proportions(std::vector<double> const &vect);
 };
         
 #endif
