@@ -6,10 +6,10 @@ void Densities::writeParameters(std::ostream &out) const
     out << 
         "BreastDensities:\n";
 
-    Globals::setPrecision(out, 2);
+    Globals::setWidthPrec(out, 3, 2);
 
     for (Density const &density: d_densities)
-        out << "  " << density << '\n';
+        out << setw(2) << ' ' << density << '\n';
 
     out.put('\n');
 }
