@@ -3,10 +3,10 @@
 
 uint16_t Density::indexOf(double prob) const
 {
-    return find_if(d_cumBirads, d_cumBirads + N_BIRADS, // visit
+    return find_if(d_cumBirads.begin(), d_cumBirads.end(), 
                 [&](double cumProb)
                 {
                     return prob <= cumProb;
                 }
-            ) - d_cumBirads;
+            ) - d_cumBirads.begin();
 }
