@@ -13,3 +13,6 @@ StringVect Distribution::s_name                     // see enums.h
 };
 
 //  "Exponential",      // EXPONENTIAL
+
+unsigned Distribution::s_width = 0;
+unsigned Distribution::s_precision = 0;
