@@ -3,10 +3,11 @@
 
 std::ostream &Distribution::insert(std::ostream &out) const
 {
-    if (d_type != N_DISTRIBUTIONS)
-        out << d_value << " (" << s_name[d_type] << ')';
-    else
+    if (d_type == N_DISTRIBUTIONS)
         out << setw(12) << ' ';
+    else
+        Globals::setWidthPrec(out, s_width, s_precision) <<
+                                d_value << " (" << s_name[d_type] << ')';
 
     return out;
 }
