@@ -6,14 +6,14 @@ double Distribution::varyProb(double orgValue) const
     for (unsigned count = 0; count != MAX_VARY_TRIES; ++count)
     {                                       
         if (
-            double ret = varyOK(orgValue); 
+            double ret = varyMean(orgValue); 
             Globals::proportion(ret)
         )
             return ret;
     }
 
     throw Exception{} << 
-        "failed to obtain spreaded proportion for " <<
+        "failed to obtain spread proportion for " <<
         orgValue << " (spread = " << d_value << 
                     ", distribution: " << name(d_type) << ')';
 }
