@@ -1,19 +1,13 @@
 #ifndef INCLUDED_ENUMS_
 #define INCLUDED_ENUMS_
 
-enum Constants
-{
-    N_BIRADS = 4,   // 4 bi-rad categories (cf. tech man. section Densities)
-    MAX_VARY_TRIES = 10, // max #attempts to obtain a valid varied value
-
-    END_AGE         = 101,
-    MAX_AGE         = END_AGE - 1,
-};
+static unsigned const END_AGE = 101;
+static unsigned const MAX_AGE = END_AGE - 1;
 
 enum VaryType
 {
-    VARY_OK,                    // every value is OK
-    VARY_POS,                   // varied values must be >= 0
+    VARY_MEAN,                  // every value is OK
+    VARY_NONNEG,                   // varied values must be >= 0
     VARY_PROB                   // varied values must be probabilities
 };
 
