@@ -22,18 +22,19 @@ class Growth
 {   
     StringVect d_base;
 
-    double d_start;
-    VSD d_mu;       
-    double d_sigma;
+    double  d_start;
 
-    AgeGroupVSDvect d_ageGroupVSDs;
+    double  d_selfSD;
+    VSD     d_selfMean;       
+
+    AgeGroupVSDvect d_doublingTime;
 
     public:
         Growth();
 
-        AgeGroupVSD const &ageGroupVSD(uint16_t idx) const; // was: group()
+        AgeGroupVSD const &ageGroupVSD(uint16_t idx) const;
 
-        void vary();
+        void vary(std::ostream &out);
 
         double start() const;
         VSD const &selfMu() const;
@@ -57,7 +58,7 @@ class Growth
 
 inline AgeGroupVSD const &Growth::ageGroupVSD(uint16_t idx) const
 {
-    return d_ageGroupVSDs[idx];
+    return d_doublingTime[idx];
 }
 
 inline double Growth::start() const
@@ -67,12 +68,12 @@ inline double Growth::start() const
 
 inline VSD const &Growth::selfMu() const
 {
-    return d_mu;
+    return d_selfMean;
 }
 
 inline double Growth::selfSigma() const
 {
-    return d_sigma;
+    return d_selfSD;
 }
 
 #endif
