@@ -3,7 +3,7 @@
 
 bool Growth::nextRange(AgeGroupVSD const &next) const
 {
-    return d_ageGroupVSDs.empty() 
+    return d_doublingTime.empty() 
            or 
-           next.beginAge() == d_ageGroupVSDs.back().endAge();
+           next.beginAge() == d_doublingTime.back().endAge();
 }
