@@ -18,21 +18,21 @@ void Growth::setDoublingTime()
         if (line == 0)
             break;
 
-        AgeGroupVSD ageGroupVSD;
+        AgeGroupVSD spec{ VARY_NONNEG, true };
 
-        if (not Parser::extract(*line, ageGroupVSD))
+        if (not Parser::extract(*line, spec))
             push = false;
 
         if (not push)
             continue;
 
-        if (not ageGroupVSD.ageGroup().nextRange(d_ageGroupVSDs))
+        if (not spec.ageGroup().nextRange(d_doublingTime))
         {
             push = false;
             continue;
         }
 
-        d_ageGroupVSDs.push_back(ageGroupVSD);
+        d_doublingTime.push_back(spec);
     }
 }
 
