@@ -23,5 +23,5 @@ Incidence::Incidence()
     for (auto &vect: d_tumorRisk)           // resize for all ages
         vect.resize(END_AGE);
 
-    setTumorRisk();                         // then set the tumor risks
+    cptTumorRisk();                         // then set the tumor risks
 }
