@@ -5,7 +5,7 @@ void Incidence::setCarrier(size_t idx)
 {
     StringVect base{ "Tumor:", "Incidence:", s_carrier[idx], "probability:" };
 
-    Params params;
+    Params params( idx );
 
     bool ok = Parser::proportion(base, params.d_prob);
 
@@ -14,12 +14,10 @@ void Incidence::setCarrier(size_t idx)
 
     base.back() = "lifetimeRisk:";
 
-    params.d_vsd[0].setMode(VSD::PROPORTION);
     ok = Parser::one(base, params.d_vsd[0]) and ok;
 
     base.back() = "meanAge:";
 
-    params.d_vsd[1].setMode(VSD::MEAN);
     ok = Parser::one(base, params.d_vsd[1]) and ok;
 
     if (ok)
