@@ -7,5 +7,5 @@ xerr("costs: " << cost);
 
     d_caseCost += cost;
 
-    d_roundCost[d_round] += round(cost);
+    d_roundCost[d_round] += round(cost);        // round(): cmath
 }
