@@ -7,6 +7,9 @@ void Loop::caseInit()
     d_deathAge = 0;                         // org: tumorDeathAge
     d_roundDetected = 0;                    // org: roundDetected
     d_selfDetected = false;                 // org: selfDetected
+    d_roundInfo.assign(d_nRounds, '0');     // attendance info per round per
+                                            // case at [idx] the info of round
+                                            // idx is stored
 
                                 // Breast bi-rad indices to use for the
                                 // ages of the screening rounds
