@@ -12,13 +12,22 @@ void Loop::iterate()
 
     for (size_t idx = 0, end = d_scenario.nIterations(); idx != end; ++idx)
     {
+        ofstream spreadStream;
+
         size_t nCases = cases();
 
         Random::instance().reinit(nCases, d_scenario.vary(), 
                                           d_scenario.generatorType());  
 
         if (d_scenario.vary())      // maybe vary the parameters
-            d_tumorInfo.vary();
+        {
+            spreadStream = outStream(Options::instance().spreadFile(), idx);
+            labels(spreadStream);
+            
+            d_modalities.vary(spreadStream);    // vary the used modalities
+            d_tumorInfo.vary(spreadStream);     // vary Beir7, Growth,
+                                                // Incidence, and Survival
+        }
 
         writeParameters(idx);       // write the actual parameter values,
 
