@@ -13,9 +13,9 @@ xerr("treatment cost entry: " << d_caseCost);
                                     // there is a tumor, detected before the
                                     // woman's natural death
     if (d_tumor and d_tumor.age() < d_naturalDeathAge) 
-        treatmentDeath();           // this results in DEATH, so the
-                                    // contition check in the original sources
-                                    // is superfluous
+        treatmentDeath();           // this results in a tumor caused death.
+                                    // (the contition check in the original
+                                    //  sources is superfluous)
 
     else                            // or a naturally caused death
     {
