@@ -7,7 +7,7 @@ void Loop::screening()
     {
         double screeningAge = d_screening.age(d_round);
 
-        if (deathOccurred(screeningAge))
+        if (leaving(screeningAge))
             return;
 
 xerr("round: " << d_round);
