@@ -3,7 +3,7 @@
 
 void Loop::writeRounds(CSVTable &tab) const
 {
-    if (not tab.stream())
+    if (not tab.stream() or d_nRounds == 0)
         return;
 
     for (size_t rnd = 0; rnd != d_nRounds; ++rnd)
