@@ -9,12 +9,14 @@ Arg::LongOption g_longOpts[] =
     Arg::LongOption{"config",       'C'},
     Arg::LongOption{"data",         'D'},
     Arg::LongOption{"death-age",    'a'},
+    Arg::LongOption{"err",          'e'},
     Arg::LongOption{"help",         'h'},
     Arg::LongOption{"last-case",    'l'},
     Arg::LongOption{"one-analysis", 'o'},
     Arg::LongOption{"parameters",   'P'},
     Arg::LongOption{"rounds",       'R'},
     Arg::LongOption{"sensitivity",  'S'},
+    Arg::LongOption{"spread",       's'},
     Arg::LongOption{"tumor-age",    't'},
     Arg::LongOption{"verbose",      'V'},
     Arg::LongOption{"version",      'v'},
@@ -26,7 +28,7 @@ auto const *g_longEnd = g_longOpts + size(g_longOpts);
 int main(int argc, char **argv)
 try
 {
-    Arg const &arg = Arg::initialize("a:B:l:C:D:hoP:R:S:t:vV",
+    Arg const &arg = Arg::initialize("a:B:el:C:D:hoP:R:S:s:t:vV",
                                       g_longOpts, g_longEnd, argc, argv);
     arg.versionHelp(usage, Icmake::version, arg.option('o') ? 0 : 1);
 
