@@ -1,4 +1,4 @@
-//#define XERR
+#define XERR
 #include "modalities.ih"
 
 Modalities::Modalities(Tumor const &tumor)
