@@ -1,12 +1,16 @@
 #ifndef INCLUDED_MODBASE_
 #define INCLUDED_MODBASE_
 
+
+// see ../modalities/README
+
+
 #include <iomanip>
 #include <unordered_map>
 
 #include "../err/err.h"
 #include "../typedefs/typedefs.h"
-#include "../specificity/specificity.h"
+#include "../agegroupvsd/agegroupvsd.h"
 
 class ModBase
 {
@@ -22,6 +26,9 @@ class ModBase
         ModBase(std::string const &id);
         virtual ~ModBase();
 
+        void vary(std::ostream &out);            // see Growth::vary()
+
+
         double sensitivity(size_t idx) const;
         double specificity(double age) const;
         uint16_t cost() const;
@@ -29,7 +36,7 @@ class ModBase
         void count(size_t round);
         void falsePositive();
         std::string const &id() const;
-        double const *dose() const;
+        VSDvect const *dose() const;
         double dose(uint16_t idx) const;
 
 //        void roundHeader(std::ostream &out) const;
@@ -38,28 +45,27 @@ class ModBase
         size_t operator[](size_t round) const;
 
     protected:
-        void costHandler(StringVect &keywords);         // sets "costs:"
-        void specificityHandler(SpecificityVect &dest,  // sets "specificity:"
-                                StringVect &keywords);
+        void costBase(StringVect &keywords);         // sets "costs:"
 
-        void doubleHandler(double *dest, StringVect const &keywords,
-                           bool  (*proportionCheck)
-                                 (double const *, unsigned) = 0);
+                                    // ageGroup and specificity 
+                                    // sets keywords: [2]: Specificity
+                                    //                [3]: ageGroup
+        void specificityBase(AgeGroupVSDvect &dest, StringVect &keywords);
+
+
+        void doseBase(VSDvect &dose, StringVect &keywords);
 
-        static void insertBirads(std::ostream &out, char const *label, 
-                                 double const *value);
-        static void insertSpecificity(std::ostream &out, unsigned fill,
-                                      SpecificityVect const &value);
 
     private:
-        virtual double const *vDose() const = 0;
+        virtual VSDvect const *vDose() const = 0;
         virtual double vDose(uint16_t idx) const = 0;
         virtual void vInsert(std::ostream &out) const = 0;
         virtual double vSensitivity(size_t idx) const = 0;
         virtual double vSpecificity(double age) const = 0;
+        virtual void vVary(std::ostream &out) = 0;
 
         static void outSpec(std::ostream &out, char const *prefix, 
-                            unsigned fill, Specificity const &spec);
+                            unsigned fill, AgeGroupVSD const &spec);
 };
 
 
@@ -93,7 +99,7 @@ inline std::string const &ModBase::id() const
     return d_id;
 }
 
-inline double const *ModBase::dose() const
+inline VSDvect const *ModBase::dose() const
 {
     return vDose();
 }
@@ -114,6 +120,11 @@ inline double ModBase::specificity(double age) const
     return vSpecificity(age);
 }
 
+inline void ModBase::vary(std::ostream &out)
+{
+    return vVary(out);
+}
+
 //inline void ModBase::roundHeader(std::ostream &out) const
 //{
 //    out << ", #" << d_id;
