@@ -3,7 +3,7 @@
 
 // static
 void ModBase::outSpec(ostream &out, char const *prefix, unsigned fill,
-                                    Specificity const &spec)
+                                    AgeGroupVSD const &spec)
 {
     out << prefix << setw(fill) << ' ' << 
                      setw(2) << spec.beginAge() << " - " << setw(2);
