@@ -3,18 +3,19 @@
 
 #include <iosfwd>
 
+#include "../vsd/vsd.h"
 #include "../modbase/modbase.h"
 
 // MRI:
 //     costs:          280
-//     sensitivity:    .94
-//     specificity:    .95
-
+//          #                   value   spread  distr.                    
+//      sensitivity:            .94     0.005  Normal
+//      specificity:            .95     0.005  Normal
 
 class MRI: public ModBase
 {
-    double d_sensitivity;
-    double d_specificity;
+    VSD d_sensitivity;
+    VSD d_specificity;
 
     StringVect d_base;
 
@@ -23,14 +24,17 @@ class MRI: public ModBase
         ~MRI() override;
 
     private:
-        void sensitivityHandler();
-        void specificityHandler();
+        void setSensitivity();
+        void setSpecificity();
 
-        double const *vDose() const override;               // 1
+        VSDvect const *vDose() const override;               // 1
         double vDose(uint16_t idx) const override;          // 2
         void vInsert(std::ostream &out) const override;
         double vSensitivity(size_t idx) const override;
         double vSpecificity(double age) const override;
+        void vVary(std::ostream &out) override;
+
+        void extract(char const *keyword, VSD &dest);
 
 };
 
