@@ -1,7 +1,7 @@
 //#define XERR
 #include "mri.ih"
 
-double const *MRI::vDose() const
+VSDvect const *MRI::vDose() const
 {
     return 0;
 }
