@@ -50,6 +50,10 @@ bool Options::alter(int optChar, std::string const &value)
             d_sensitivityFile[ANALYSIS] = value;
         break;
 
+        case 's':
+            d_spreadFile[ANALYSIS] = value;
+        break;
+
 
 //        case 'T':
 //            setFile(d_cumTotalriskFile = value, 'T');
