@@ -1,19 +1,28 @@
 //#define XERR
 #include "screening.ih"
 
-void Screening::addRound(LineInfo const &lineInfo)
+    // false: round: none was specified
+    // true: round: age modality/ties was specified
+
+bool Screening::addRound(LineInfo *noneLine, LineInfo const &lineInfo)
 {
     Round round(d_modalities.modalityIDs());
 
     auto in = Parser::extract(lineInfo, round);   // extracts the age
 
+    if (round.none())
+    {
+        *noneLine = lineInfo;               // save the last round: none line
+        return false;
+    }
+
     if (not in)
-        return;
+        return true;
 
     if (not increasingAge(round))
     {
         Err::msg(Err::ROUND_AGES_DONT_INC) << endl;
-        return;
+        return true;
     }
 
     string modality;
@@ -32,8 +41,9 @@ void Screening::addRound(LineInfo const &lineInfo)
         }
 
         Err::msg(context) << endl;
-        return;
+        return true;
     }
 
     d_roundVect.push_back(move(round));
+    return true;
 }
