@@ -5,7 +5,7 @@ DoubleVect Screening::ages() const
 {
     DoubleVect ret;
 
-    for (auto const &round: d_rounds)
+    for (auto const &round: d_roundVect)
         ret.push_back(round.age());
 
     return ret;
