@@ -1,10 +1,11 @@
-//#define XERR
+#define XERR
 #include "screening.ih"
 
 Screening::Screening(Modalities const &modalities)
 :
     d_modalities(modalities),
-    d_base{ "Screening:", "" }
+    d_base{ "Screening:", "" },
+    d_errRiskVector(Arg::instance().option('e') ? errRisk1404 : errRisk1405)
 {
     setAttendanceRate();
     setRounds();
