@@ -1,4 +1,4 @@
-//#define XERR
+#define XERR
 #include "simulator.ih"
 
 //code
@@ -10,23 +10,10 @@ void Simulator::run()
                                             // read the next analysis specs
         string spec = (this->*d_nextSpecs)();   
 
-        Error::instance().reset();
+        emsg.setCount(0);
+
         Analysis analysis{ istringstream{ spec }, lineNr };
         analysis.run();                     // run the simulation
     }
 }
 //=
-
-
-//    Costs costs{ d_confFile };
-//
-//    for (Analysis &analysis: d_analyses)
-//    {
-//        if (Globals::nErrors() != 0)
-//            throw 1;
-//
-//        Loop loop{ analysis, costs };
-//        loop.iterate();
-//    }
-
-
