@@ -13,12 +13,12 @@
 
 class Survival
 {
-    VSDvect d_vsd;
+    VSDvect d_vsdVect;
 
     public:
         Survival();
 
-        void vary();
+        void vary(std::ostream &out);
         VSD const &operator[](size_t idx) const;
 
         void writeParameters(std::ostream &out) const;
@@ -26,7 +26,7 @@ class Survival
         
 inline VSD const &Survival::operator[](size_t idx) const
 {
-    return d_vsd[idx];
+    return d_vsdVect[idx];
 }
 
 #endif
