@@ -32,7 +32,7 @@ void Tumor::reset()
     d_startVolume = volume(d_growth.start());
 
     AgeGroupVSD const &group = d_growth.ageGroupVSD(idx);
-    d_doublingDays = random.logNormal(group.mean().value(), group.stdDev());
+    d_doublingDays = random.logNormal(group.value(), group.stdDev());
 
     d_doublingYears = d_doublingDays / N_YEARDAYS;
 
