@@ -23,7 +23,7 @@ class TumorInfo: public Globals
 
     public:
                                  
-        void vary();                            // vary parameters 
+        void vary(std::ostream &out);           // vary parameters 
                                     
         Incidence const &incidence() const;
     
